vdoc.cli package | vdoc 0.19.0 documentation

Skip to content

# vdoc.cli package

## Submodules

## vdoc.cli.main module

Contains the main CLI entry point.

class vdoc.cli.main.LogLevel(value, names=<not given>, *values, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `str`, `Enum`

  Enum for log levels for typer.

  DEBUG = 'DEBUG'
  ERROR = 'ERROR'
  INFO = 'INFO'
  WARNING = 'WARNING'

vdoc.cli.main.check_for_default_credentials()

  Checks the configured API credentials and warns if the default credentials are used.

  Return type:

    `None`

vdoc.cli.main.print_version(do_print)

  Prints the version of the software.

  Parameters:

    do_print (`bool`) – If the version shall be printed.

  Raises:

    typer.Exit – After the version was printed.

  Return type:

    `None`

## vdoc.cli.run module

This module defines the typer run method.

## Module contents

Contains the CLI.

vdoc.api.routes package
vdoc.exceptions package